@@ -98,9 +98,9 @@ KMMainWin::KMMainWin(QWidget *)
     }
     setStandardToolBarMenuEnabled(true);
 
-    KStandardAction::configureToolbars(this, &KMMainWin::slotEditToolbars, actionCollection());
+    KStandardActions::configureToolbars(this, &KMMainWin::slotEditToolbars, actionCollection());
 
-    KStandardAction::keyBindings(this, &KMMainWin::slotConfigureShortcuts, actionCollection());
+    KStandardActions::keyBindings(this, &KMMainWin::slotConfigureShortcuts, actionCollection());
 
     mShowMenuBarAction = KStandardAction::showMenubar(this, &KMMainWin::slotToggleMenubar, actionCollection());
     if (menuBar()) {
@@ -116,11 +116,13 @@ KMMainWin::KMMainWin(QWidget *)
         });
     }
 
-    KStandardAction::quit(this, &KMMainWin::slotQuit, actionCollection());
+    KStandardActions::quit(this, &KMMainWin::slotQuit, actionCollection());
     createGUI(QStringLiteral("kmmainwin.rc"));
 
     // must be after createGUI, otherwise e.g toolbar settings are not loaded
-    setAutoSaveSettings(KMKernel::self()->config()->group(QStringLiteral("Main Window")));
+    setStateConfigGroup(QStringLiteral("Main Window"));
+    // The next line implicitly calls applyMainWindowSettings(stateConfigGroup())
+    setAutoSaveSettings(stateConfigGroup(), true);
 
     connect(PimCommon::BroadcastStatus::instance(), &PimCommon::BroadcastStatus::statusMsg, this, &KMMainWin::displayStatusMessage);
 
@@ -168,9 +170,9 @@ void KMMainWin::updateHamburgerMenu()
 {
     delete mHamburgerMenu->menu();
     auto menu = new QMenu(this);
-    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Open)));
-    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::SaveAs)));
-    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Print)));
+    menu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::Open)));
+    menu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::SaveAs)));
+    menu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::Print)));
     menu->addSeparator();
     menu->addAction(actionCollection()->action(QStringLiteral("check_mail")));
     menu->addAction(actionCollection()->action(QStringLiteral("check_mail_in")));
@@ -182,7 +184,7 @@ void KMMainWin::updateHamburgerMenu()
     menu->addAction(actionCollection()->action(QStringLiteral("kmail_configure_notifications")));
     menu->addSeparator();
 
-    menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
+    menu->addAction(actionCollection()->action(KStandardActions::name(KStandardActions::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -250,7 +252,7 @@ void KMMainWin::slotUpdateGui()
     mKMMainWidget->clearPluginActions();
 
     createGUI(QStringLiteral("kmmainwin.rc"));
-    applyMainWindowSettings(KMKernel::self()->config()->group(QStringLiteral("Main Window")));
+    applyMainWindowSettings(stateConfigGroup());
 
     // plug dynamically created actions again
     mKMMainWidget->initializeFilterActions(false);
